@@ -8,7 +8,7 @@ import numpy as np
 from .utils import readToGray
 from .utils import saveNumpy
 
-def preprocess(DIR, classes, name, resized_size=224, train_size=None, isNormalize=False, isShuffle=True, isSave = True):
+def preprocess(DIR, classes, name, IMG_SIZE=224, train_size=None, isNormalize=False, isShuffle=True, isSave = True):
     """
     Reads Images in base directory DIR
     Returns
@@ -51,7 +51,7 @@ def preprocess(DIR, classes, name, resized_size=224, train_size=None, isNormaliz
                         image_path = os.path.join(class_path, image)
 
                         # Returns image RESIZED and GRAY
-                        gray = readToGray(image_path, resized_size)
+                        gray = readToGray(image_path, IMG_SIZE)
                         # Normalizing
                         if isNormalize is True:
                             gray = normalize(gray)
@@ -76,18 +76,16 @@ def preprocess(DIR, classes, name, resized_size=224, train_size=None, isNormaliz
                     print('[INFO] Saving as .npy file')
                 elif '.npz' in name:
                     print('[INFO] Saving as .npz file')
-                since = time.time()
                 
+                since = time.time()
                 # Saving
                 saveNumpy(name, train)
 
                 end = time.time()
+                
                 time_elapsed = end-since
-                if '.npy' in name:
-                    print('{}.npy saved! Took {:.0f}m {:.0f}s'.format(name, time_elapsed // 60, time_elapsed % 60))
 
-                elif '.npz' in name:
-                    print('{}.npz saved! Took {:.0f}m {:.0f}s'.format(name, time_elapsed // 60, time_elapsed % 60))
+                print('{} saved! Took {:.0f}m {:.0f}s'.format(name, time_elapsed // 60, time_elapsed % 60))
 
             #Returns Training Set
             end_preprocess = time.time()
